function Q = summ2punktgauss(f,a,b,N)
%
% function Q = summ2punktgauss(f,a,b,N)
%
% Approximiere das bestimmte Integral von f(x) von a bis b mit der summierten
% 2-Punkte Gauss Quadraturregel.
%
% Parameters: f   ... die zu integrierende Funktion 
%             a,b ... linke/rechte Integrations-Grenzen
%             N   ... Anzahl Teilintervalle
%
% Returns: Q ... Approximation des Integrals

  % Vektor [x_0, x_1, ..., x_N] mit x_0 = a und x_N = b
  x = linspace(a,b,N+1);

  % Teilintervallbreite
  h = (b-a)/N;
  
  % Summierte 2-Punkte Gauss Quadraturregel
  Q = 0.;
  for i=1:N
    xmid = 0.5*(x(i) + x(i+1));
    x0 = xmid - 0.5/sqrt(3.)*h;
    x1 = xmid + 0.5/sqrt(3.)*h;
    Q = Q + 0.5*h*(f(x0) + f(x1));
  end
