function Q = summsimpsonregel(f,a,b,N)
%
% function Q = summsimpsonregel(f,a,b,N)
%
% Approximiere das bestimmte Integral von f(x) von a bis b mit der summierten
% Simpsonregel.
%
% Parameters: f   ... die zu integrierende Funktion 
%             a,b ... linke/rechte Integrations-Grenzen
%             N   ... Anzahl Teilintervalle
%
% Returns: Q ... Approximation des Integrals

  % Vektor [x_0, x_1, ..., x_N] mit x_0 = a und x_N = b
  x = linspace(a,b,2*N+1);

  % Teilintervallbreite
  h = (b-a)/N;

  % Summierte Simpsonregel
  fx = f(x); % Werte f in x aus
  Q = h/6.*(fx(1) + 2*sum(fx(3:2:end-2)) + 4*sum(fx(2:2:end-1))+ fx(end));

end
